<?php
/*
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2015 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_'))
	exit;

class StatsProfitOrders extends ModuleGrid
{
	private $html = null;
	private $query = null;
	private $columns = null;
	private $default_sort_column = null;
	private $default_sort_direction = null;
	private $empty_message = null;
	private $paging_message = null;

	public function __construct()
	{
		$this->name = 'statsprofitorders';
		$this->tab = 'analytics_stats';
		$this->version = '1.0';
		$this->author = 'zimmer-media-office';
		$this->need_instance = 0;

		parent::__construct();

		$this->default_sort_column = 'date_add';
		$this->default_sort_direction = 'ASC';
		$this->empty_message = $this->l('An empty record-set was returned.');
		$this->paging_message = sprintf($this->l('Displaying %1$s of %2$s'), '{0} - {1}', '{2}');

		$this->columns = array(
			array(
				'id' => 'number',
				'header' => $this->l('Order ID'),
				'dataIndex' => 'number',
				'align' => 'right'
			),
			array(
				'id' => 'invoice_number',
				'header' => $this->l('Invoice Number'),
				'dataIndex' => 'invoice_number',
				'align' => 'right'
			),
			array(
				'id' => 'invoice_date',
				'header' => $this->l('Invoice Date'),
				'dataIndex' => 'invoice_date',
				'align' => 'right'
			),
			array(
				'id' => 'paid',
				'header' => $this->l('Paid'),
				'dataIndex' => 'paid',
				'align' => 'right'
			),
			array(
				'id' => 'total',
				'header' => $this->l('Total'),
				'dataIndex' => 'total',
				'align' => 'right'
			),
			array(
				'id' => 'shipping',
				'header' => $this->l('Shipping'),
				'dataIndex' => 'shipping',
				'align' => 'right'
			),
			array(
				'id' => 'TaxTotal',
				'header' => $this->l('Tax'),
				'dataIndex' => 'TaxTotal',
				'align' => 'right'
			),
			array(
				'id' => 'cost',
				'header' => $this->l('Cost'),
				'dataIndex' => 'cost',
				'align' => 'right'
			),
			array(
				'id' => 'totalDiscount',
				'header' => $this->l('Discount'),
				'dataIndex' => 'totalDiscount',
				'align' => 'right'
			),
			array(
				'id' => 'profit',
				'header' => $this->l('Profit'),
				'dataIndex' => 'profit',
				'align' => 'right'
			)
		);

		$this->displayName = $this->l('Orders Profit');
		$this->description = $this->l('Adds a list of the orders profit to the Stats dashboard.');
		$this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
	}

	public function install()
	{
		return (parent::install() && $this->registerHook('AdminStatsModules'));
	}

	public function hookAdminStatsModules($params)
	{
		$engine_params = array(
			'id' => 'id_product',
			'title' => $this->displayName,
			'columns' => $this->columns,
			'defaultSortColumn' => $this->default_sort_column,
			'defaultSortDirection' => $this->default_sort_direction,
			'emptyMessage' => $this->empty_message,
			'pagingMessage' => $this->paging_message
		);

		if (Tools::getValue('export'))
			$this->csvExport($engine_params);

		return '<div class="panel-heading">'.$this->displayName.'</div>
		'.$this->engine($engine_params).'
		<a class="btn btn-default export-csv" href="'.Tools::safeOutput($_SERVER['REQUEST_URI'].'&export=1').'">
			<i class="icon-cloud-upload"></i> '.$this->l('CSV Export').'
		</a>';
		
		return $this->html;
	}

	public function getData()
	{
		$currency = new Currency(Configuration::get('PS_CURRENCY_DEFAULT'));
		$date_between = $this->getDate();
		$array_date_between = explode(' AND ', $date_between);

		$this->query = 'SELECT o.id_order as number, o.invoice_number as invoice_number, DATE_FORMAT(o.invoice_date, \'%d.%m.%Y\') as invoice_date, ROUND( o.total_paid / o.conversion_rate , 2 ) as paid,  ROUND((o.total_paid / o.conversion_rate + o.total_discounts_tax_incl / o.conversion_rate), 2 ) as total, ROUND((o.total_paid / o.conversion_rate - total_paid_tax_excl / o.conversion_rate) , 2 ) as TaxTotal, ROUND( o.total_shipping_tax_excl / o.conversion_rate , 2 ) AS shipping, ROUND(SUM(o.total_discounts_tax_incl / o.conversion_rate),2) as totalDiscount, ((
			SELECT ROUND(SUM(p.wholesale_price / o.conversion_rate * od.product_quantity / o.conversion_rate), 2)
                        FROM '._DB_PREFIX_.'order_detail od
			LEFT JOIN '._DB_PREFIX_.'product p ON od.product_id = p.id_product
			LEFT JOIN '._DB_PREFIX_.'product_attribute pa ON pa.id_product_attribute = od.product_attribute_id
			WHERE od.id_order = o.`id_order`
		)) AS cost,
		((
			SELECT ROUND(o.`total_paid` / o.conversion_rate  - SUM(p.wholesale_price / o.conversion_rate * od.product_quantity) , 2)
			FROM '._DB_PREFIX_.'order_detail od
			LEFT JOIN '._DB_PREFIX_.'product p ON od.product_id = p.id_product
			LEFT JOIN '._DB_PREFIX_.'product_attribute pa ON pa.id_product_attribute = od.product_attribute_id
			WHERE od.id_order = o.`id_order`
		) -		
		(ROUND( o.total_paid_tax_incl / o.conversion_rate - o.total_paid_tax_excl / o.conversion_rate, 2 )) -
		ROUND( o.total_shipping_tax_excl / o.conversion_rate , 2 )
		) AS profit
		FROM `'._DB_PREFIX_.'orders` o		
		WHERE o.valid =1
AND o.invoice_date BETWEEN '.$this->getDate().'
		GROUP BY o.`id_order`
		';
		
		
		
		

		if (Validate::IsName($this->_sort))
		{
			$this->query .= ' ORDER BY `'.bqSQL($this->_sort).'`';
			if (isset($this->_direction) && Validate::isSortDirection($this->_direction))
				$this->query .= ' '.$this->_direction;
		}


		$values = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS($this->query);
		foreach ($values as &$value)
		{
			$value['total'] = Tools::displayPrice($value['total'], $currency);
		}
		unset($value);

		$this->_values = $values;
		$this->_totalCount = Db::getInstance(_PS_USE_SQL_SLAVE_)->getValue('SELECT FOUND_ROWS()');
	}
}
